==> netherblocks-1.0.0.tar.gz: netherblocks-1.0.0/info/devzero/jerry/plugins/bukkit/netherblocks/NetherBlocksBlockListener.java <==
package info.devzero.jerry.plugins.bukkit.netherblocks;

import org.bukkit.Location;
import org.bukkit.Material;
import org.bukkit.block.Block;
import org.bukkit.event.block.BlockListener;
import org.bukkit.event.block.BlockDamageEvent;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;

/*
 * NetherBlocks - a Bukkit plugin that allows users to get Nether blocks using gold tools
 * Copyright (C) 2011 Jerry <j3rry1337@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 * NetherBlocks block listener
 * @author Jerry <j3rry1337@gmail.com>
 */
public class NetherBlocksBlockListener extends BlockListener {
    private final NetherBlocks plugin;

    public NetherBlocksBlockListener(final NetherBlocks plugin) {
        this.plugin = plugin;
    }

    public void onBlockDamage(BlockDamageEvent event) {
        Block block = event.getBlock();
        Player player = event.getPlayer();
        Location location = block.getLocation();
        
        if (event.isCancelled() || event.getDamageLevel() != org.bukkit.block.BlockDamageLevel.STOPPED) {
        	return;
        }

        // Gold shovel broke sand, make it drop Soul Sand
        if (player.getItemInHand().getTypeId() == 284 && block.getTypeId() == 12) {
        	// stop normal drop
        	event.setCancelled(true);
        	block.setType(Material.AIR);
        	block.getWorld().dropItemNaturally(location, new ItemStack(Material.SOUL_SAND, 1));
        }
        
        // Gold shovel broke dirt, make it drop Glowstone Dust
        if (player.getItemInHand().getTypeId() == 284 && (block.getTypeId() == 2 || block.getTypeId() == 3)) {
        	// stop normal drop
        	event.setCancelled(true);
        	block.setType(Material.AIR);
        	
        	// drop random amount of Glowstone Dust
        	int num = 2 + (int) (Math.random() * (3));
			for (int i = 0; i < num; i++)
			{
				block.getWorld().dropItemNaturally(location, new ItemStack(Material.GLOWSTONE_DUST, 1));
			}
        }
        
        // Gold pickaxe broke stone, make it drop Netherrack
        if (player.getItemInHand().getTypeId() == 285 && block.getTypeId() == 1) {
        	// stop normal drop
        	event.setCancelled(true);
        	block.setType(Material.AIR);
        	block.getWorld().dropItemNaturally(location, new ItemStack(Material.NETHERRACK, 1));
        }
    }
}

==> netherblocks-1.1.0.tar.gz: netherblocks-1.1.0/info/devzero/jerry/plugins/bukkit/netherblocks/NetherBlocksBlockListener.java <==
package info.devzero.jerry.plugins.bukkit.netherblocks;

import java.util.Arrays;

import org.bukkit.Location;
import org.bukkit.Material;
import org.bukkit.block.Block;
import org.bukkit.event.block.BlockListener;
import org.bukkit.event.block.BlockDamageEvent;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;

/*
 * NetherBlocks - a Bukkit plugin that allows users to get Nether blocks using gold tools
 * Copyright (C) 2011 Jerry <j3rry1337@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 * NetherBlocks block listener
 * @author Jerry <j3rry1337@gmail.com>
 */
public class NetherBlocksBlockListener extends BlockListener {
    private final NetherBlocks plugin;

    public NetherBlocksBlockListener(final NetherBlocks plugin) {
        this.plugin = plugin;
    }

    public void onBlockDamage(BlockDamageEvent event) {
        Block block = event.getBlock();
        Player player = event.getPlayer();
        Location location = block.getLocation();
        
        if (event.isCancelled() || event.getDamageLevel() != org.bukkit.block.BlockDamageLevel.STOPPED) {
        	return;
        }

        // Gold shovel broke [insert configured block here], make it drop Soul Sand
        if (player.getItemInHand().getTypeId() == 284 && plugin.getConfiguration().getIntList("soulsandBlocks", Arrays.asList(12)).contains(block.getTypeId())) {
        	// stop normal drop
        	event.setCancelled(true);
        	block.setType(Material.AIR);
        	block.getWorld().dropItemNaturally(location, new ItemStack(Material.SOUL_SAND, 1));
        }
        
        // Gold shovel broke [insert configured block here], make it drop Glowstone Dust
        if (player.getItemInHand().getTypeId() == 284 && plugin.getConfiguration().getIntList("glowstoneBlocks", Arrays.asList(2,3)).contains(block.getTypeId())) {
        	// stop normal drop
        	event.setCancelled(true);
        	block.setType(Material.AIR);
        	
        	// drop random amount of Glowstone Dust
        	int min = plugin.getConfiguration().getInt("glowstoneMin", 2);
        	int max = plugin.getConfiguration().getInt("glowstoneMax", 4);
        	int num = min + (int) (Math.random() * ((max - min) + 1));
			for (int i = 0; i < num; i++)
			{
				block.getWorld().dropItemNaturally(location, new ItemStack(Material.GLOWSTONE_DUST, 1));
			}
        }
        
        // Gold pickaxe broke [insert configured block here], make it drop Netherrack
        if (player.getItemInHand().getTypeId() == 285 && plugin.getConfiguration().getIntList("netherrackBlocks", Arrays.asList(1)).contains(block.getTypeId())) {
        	// stop normal drop
        	event.setCancelled(true);
        	block.setType(Material.AIR);
        	block.getWorld().dropItemNaturally(location, new ItemStack(Material.NETHERRACK, 1));
        }
    }
}
